screenWidth property
double
get
screenWidth
Gets the current width of the screen or object containing this context.
Implementation
double get screenWidth => MediaQuery.sizeOf(this).width;
Gets the current width of the screen or object containing this context.
double get screenWidth => MediaQuery.sizeOf(this).width;